@@ -1,5 +1,5 @@
 #!/usr/bin/python -OO
-# Copyright 2008-2012 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2015 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -19,15 +19,18 @@
 sabnzbd.articlecache - Article cache handling
 """
 
+import sys
 import logging
 import threading
 
 import sabnzbd
 from sabnzbd.decorators import synchronized
-from sabnzbd.constants import GIGI
+from sabnzbd.constants import GIGI, ANFO, Status
 
 
 ARTICLE_LOCK = threading.Lock()
+
+
 class ArticleCache(object):
     do = None
 
@@ -42,7 +45,7 @@ class ArticleCache(object):
 
     @synchronized(ARTICLE_LOCK)
     def cache_info(self):
-        return (len(self.__article_list), self.__cache_size, self.__cache_limit_org)
+        return ANFO(len(self.__article_list), abs(self.__cache_size), self.__cache_limit_org)
 
     @synchronized(ARTICLE_LOCK)
     def new_limit(self, limit):
@@ -53,18 +56,35 @@ class ArticleCache(object):
         else:
             self.__cache_limit = min(limit, GIGI)
 
+    @synchronized(ARTICLE_LOCK)
+    def reserve_space(self, data):
+        """ Is there space left in the set limit? """
+        data_size = sys.getsizeof(data)*64
+        self.__cache_size += data_size
+        if self.__cache_size + data_size > self.__cache_limit:
+            return False
+        else:
+            return True
+
+    @synchronized(ARTICLE_LOCK)
+    def free_reserve_space(self, data):
+        """ Remove previously reserved space """
+        data_size = sys.getsizeof(data)*64
+        self.__cache_size -= data_size
+        return self.__cache_size + data_size < self.__cache_limit
+
 
     @synchronized(ARTICLE_LOCK)
     def save_article(self, article, data):
         nzf = article.nzf
         nzo = nzf.nzo
 
-        if nzf.deleted or nzo.deleted:
+        if nzo.is_gone():
             # Do not discard this article because the
             # file might still be processed at this moment!!
             if sabnzbd.LOG_ALL:
-                logging.debug("%s would be discarded", article)
-            # return
+                logging.debug("%s is discarded", article)
+            return
 
         saved_articles = article.nzf.nzo.saved_articles
 
@@ -79,16 +99,16 @@ class ArticleCache(object):
                 data_size = len(data)
 
                 while (self.__cache_size > (self.__cache_limit - data_size)) \
-                and self.__article_list:
-                    ## Flush oldest article in cache
+                        and self.__article_list:
+                    # Flush oldest article in cache
                     old_article = self.__article_list.pop(0)
                     old_data = self.__article_table.pop(old_article)
                     self.__cache_size -= len(old_data)
-                    ## No need to flush if this is a refreshment article
+                    # No need to flush if this is a refreshment article
                     if old_article != article:
                         self.__flush_article(old_article, old_data)
 
-                ## Does our article fit into our limit now?
+                # Does our article fit into our limit now?
                 if (self.__cache_size + data_size) <= self.__cache_limit:
                     self.__add_to_cache(article, data)
                 else:
@@ -113,7 +133,7 @@ class ArticleCache(object):
                                      do_pickle=False, silent=True)
 
         if article in nzo.saved_articles:
-            nzo.saved_articles.remove(article)
+            nzo.remove_saved_article(article)
 
         return data
 
@@ -141,20 +161,20 @@ class ArticleCache(object):
         nzf = article.nzf
         nzo = nzf.nzo
 
-        if nzf.deleted or nzo.deleted:
+        if nzo.is_gone():
             # Do not discard this article because the
             # file might still be processed at this moment!!
             if sabnzbd.LOG_ALL:
-                logging.debug("%s would be discarded", article)
-            # return
+                logging.debug("%s is discarded", article)
+            return
 
         art_id = article.get_art_id()
         if art_id:
             if sabnzbd.LOG_ALL:
                 logging.debug("Flushing %s to disk", article)
-            # Save data, but don't complain when destistation folder is missing
+            # Save data, but don't complain when destination folder is missing
             # because this flush may come after completion of the NZO.
-            sabnzbd.save_data(data, art_id, nzo.workpath, do_pickle = False, silent=True)
+            sabnzbd.save_data(data, art_id, nzo.workpath, do_pickle=False, silent=True)
         else:
             logging.warning("Flushing %s failed -> no art_id", article)
 
@@ -170,5 +190,5 @@ class ArticleCache(object):
             logging.debug("Added %s to cache", article)
 
 
-### Create the instance
+# Create the instance
 ArticleCache()
