@@ -1,5 +1,5 @@
 #!/usr/bin/python -OO
-# Copyright 2008-2012 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2015 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -21,7 +21,6 @@ sabnzbd.assembler - threaded assembly/decoding of files
 
 import os
 import Queue
-import binascii
 import logging
 import struct
 import re
@@ -35,21 +34,20 @@ except:
     new_md5 = md5.new
 
 import sabnzbd
-from sabnzbd.misc import get_filepath, sanitize_filename, get_unique_path, renamer, \
-                         set_permissions, flag_file
-from sabnzbd.constants import QCHECK_FILE
+from sabnzbd.misc import get_filepath, sanitize_filename, get_unique_filename, renamer, \
+    set_permissions, flag_file, long_path, clip_path
+from sabnzbd.constants import QCHECK_FILE, Status
 import sabnzbd.cfg as cfg
 from sabnzbd.articlecache import ArticleCache
 from sabnzbd.postproc import PostProcessor
 import sabnzbd.downloader
 from sabnzbd.utils.rarfile import RarFile, is_rarfile
-from sabnzbd.encoding import latin1, unicoder, is_utf8
+from sabnzbd.encoding import unicoder, is_utf8
 from sabnzbd.rating import Rating
 
 
-#------------------------------------------------------------------------------
 class Assembler(Thread):
-    do = None # Link to the instance of this method
+    do = None  # Link to the instance of this method
 
     def __init__(self, queue=None):
         Thread.__init__(self)
@@ -83,26 +81,26 @@ class Assembler(Thread):
 
                 dupe = nzo.check_for_dupe(nzf)
 
-                filepath = get_filepath(cfg.download_dir.get_path(), nzo, filename)
+                filepath = get_filepath(long_path(cfg.download_dir.get_path()), nzo, filename)
 
                 if filepath:
                     logging.info('Decoding %s %s', filepath, nzf.type)
                     try:
                         filepath = _assemble(nzf, filepath, dupe)
                     except IOError, (errno, strerror):
-                        if nzo.deleted:
+                        if nzo.is_gone():
                             # Job was deleted, ignore error
                             pass
                         else:
                             # 28 == disk full => pause downloader
                             if errno == 28:
-                                logging.error(Ta('Disk full! Forcing Pause'))
+                                logging.error(T('Disk full! Forcing Pause'))
                             else:
-                                logging.error(Ta('Disk error on creating file %s'), latin1(filepath))
+                                logging.error(T('Disk error on creating file %s'), clip_path(filepath))
                             # Pause without saving
                             sabnzbd.downloader.Downloader.do.pause(save=False)
                     except:
-                        logging.error('Fatal error in Assembler', exc_info=True)
+                        logging.error(T('Fatal error in Assembler'), exc_info=True)
                         break
 
                     nzf.remove_admin()
@@ -115,18 +113,18 @@ class Assembler(Thread):
 
                     if check_encrypted_rar(nzo, filepath):
                         if cfg.pause_on_pwrar() == 1:
-                            logging.warning(Ta('WARNING: Paused job "%s" because of encrypted RAR file'), latin1(nzo.final_name))
+                            logging.warning(T('WARNING: Paused job "%s" because of encrypted RAR file'), nzo.final_name)
                             nzo.pause()
                         else:
-                            logging.warning(Ta('WARNING: Aborted job "%s" because of encrypted RAR file'), latin1(nzo.final_name))
+                            logging.warning(T('WARNING: Aborted job "%s" because of encrypted RAR file'), nzo.final_name)
                             nzo.fail_msg = T('Aborted, encryption detected')
                             import sabnzbd.nzbqueue
                             sabnzbd.nzbqueue.NzbQueue.do.end_job(nzo)
 
                     unwanted = rar_contains_unwanted_file(filepath)
                     if unwanted:
-                        logging.warning(Ta('WARNING: In "%s" unwanted extension in RAR file. Unwanted file is %s '), latin1(nzo.final_name), unwanted)
-                        logging.debug(Ta('Unwanted extension is in rar file %s'), filepath)
+                        logging.warning(T('WARNING: In "%s" unwanted extension in RAR file. Unwanted file is %s '), nzo.final_name, unwanted)
+                        logging.debug(T('Unwanted extension is in rar file %s'), filepath)
                         if cfg.action_on_unwanted_extensions() == 1 and nzo.unwanted_ext == 0:
                             logging.debug('Unwanted extension ... pausing')
                             nzo.unwanted_ext = 1
@@ -139,14 +137,14 @@ class Assembler(Thread):
 
                     filter, reason = nzo_filtered_by_rating(nzo)
                     if filter == 1:
-                        logging.warning(Ta('WARNING: Paused job "%s" because of rating (%s)'), latin1(nzo.final_name), reason)
+                        logging.warning(Ta('WARNING: Paused job "%s" because of rating (%s)'), nzo.final_name, reason)
                         nzo.pause()
                     elif filter == 2:
-                        logging.warning(Ta('WARNING: Aborted job "%s" because of rating (%s)'), latin1(nzo.final_name), reason)
+                        logging.warning(Ta('WARNING: Aborted job "%s" because of rating (%s)'), nzo.final_name, reason)
                         nzo.fail_msg = T('Aborted, rating filter matched (%s)') % reason
                         import sabnzbd.nzbqueue
                         sabnzbd.nzbqueue.NzbQueue.do.end_job(nzo)
-                                                   
+
                     nzf.completed = True
             else:
                 sabnzbd.nzbqueue.NzbQueue.do.remove(nzo.nzo_id, add_to_history=False, cleanup=False)
@@ -168,48 +166,26 @@ def _assemble(nzf, path, dupe):
     else:
         md5 = None
 
-    _type = nzf.type
     decodetable = nzf.decodetable
 
     for articlenum in decodetable:
+        # Break if deleted during writing
+        if nzf.nzo.status is Status.DELETED:
+            break
+
+        # Sleep to allow decoder/assembler switching
         sleep(0.001)
         article = decodetable[articlenum]
 
         data = ArticleCache.do.load_article(article)
 
         if not data:
-            logging.info(Ta('%s missing'), article)
+            logging.info(T('%s missing'), article)
         else:
             # yenc data already decoded, flush it out
-            if _type == 'yenc':
-                fout.write(data)
-                if md5: md5.update(data)
-            # need to decode uu data now
-            elif _type == 'uu':
-                data = data.split('\r\n')
-
-                chunks = []
-                for line in data:
-                    if not line:
-                        continue
-
-                    if line == '-- ' or line.startswith('Posted via '):
-                        continue
-                    try:
-                        tmpdata = binascii.a2b_uu(line)
-                        chunks.append(tmpdata)
-                    except binascii.Error, msg:
-                        ## Workaround for broken uuencoders by
-                        ##/Fredrik Lundh
-                        nbytes = (((ord(line[0])-32) & 63) * 4 + 5) / 3
-                        try:
-                            tmpdata = binascii.a2b_uu(line[:nbytes])
-                            chunks.append(tmpdata)
-                        except binascii.Error, msg:
-                            logging.info('Decode failed in part %s: %s', article.article, msg)
-                data = ''.join(chunks)
-                fout.write(data)
-                if md5: md5.update(data)
+            fout.write(data)
+            if md5:
+                md5.update(data)
 
     fout.flush()
     fout.close()
@@ -274,7 +250,7 @@ def GetMD5Hashes(fname, force=False):
 
 
 def ParseFilePacket(f, header):
-    """ Look up and analyse a FileDesc package """
+    """ Look up and analyze a FileDesc package """
 
     nothing = None, None
 
@@ -283,14 +259,14 @@ def ParseFilePacket(f, header):
 
     # Length must be multiple of 4 and at least 20
     len = struct.unpack('<Q', f.read(8))[0]
-    if int(len/4)*4 != len or len < 20:
+    if int(len / 4) * 4 != len or len < 20:
         return nothing
 
     # Next 16 bytes is md5sum of this packet
     md5sum = f.read(16)
 
     # Read and check the data
-    data = f.read(len-32)
+    data = f.read(len - 32)
     md5 = new_md5()
     md5.update(data)
     if md5sum != md5.digest():
@@ -306,9 +282,9 @@ def ParseFilePacket(f, header):
 
     # See if it's the right packet and get name + hash
     for offset in range(0, len, 8):
-        if data[offset:offset+16] == "PAR 2.0\0FileDesc":
-            hash = data[offset+32:offset+48]
-            filename = data[offset+72:].strip('\0')
+        if data[offset:offset + 16] == "PAR 2.0\0FileDesc":
+            hash = data[offset + 32:offset + 48]
+            filename = data[offset + 72:].strip('\0')
             return filename, hash
 
     return nothing
@@ -334,13 +310,15 @@ def is_cloaked(path, names):
 def check_encrypted_rar(nzo, filepath):
     """ Check if file is rar and is encrypted """
     encrypted = False
-    if  not nzo.password and not nzo.meta.get('password') and cfg.pause_on_pwrar() and is_rarfile(filepath):
+    if nzo.encrypted == 0 and not nzo.password and not nzo.meta.get('password') and cfg.pause_on_pwrar() and is_rarfile(filepath):
         try:
             zf = RarFile(filepath, all_names=True)
             encrypted = zf.encrypted or is_cloaked(filepath, zf.namelist())
-            if encrypted and int(nzo.encrypted) < 2 and not nzo.reuse:
+            if encrypted and not nzo.reuse:
                 nzo.encrypted = 1
             else:
+                # Don't check other files
+                nzo.encrypted = -1
                 encrypted = False
             zf.close()
             del zf
@@ -355,13 +333,13 @@ def rar_contains_unwanted_file(filepath):
     # returns False if no unwanted extensions are found in the rar file
     # returns name of file if unwanted extension is found in the rar file
     unwanted = None
-    if is_rarfile(filepath):
-        #logging.debug('rar file to check: %s',filepath)
-        #logging.debug('unwanted extensions are: %s', cfg.unwanted_extensions())
+    if cfg.unwanted_extensions() and is_rarfile(filepath):
+        # logging.debug('rar file to check: %s',filepath)
+        # logging.debug('unwanted extensions are: %s', cfg.unwanted_extensions())
         try:
             zf = RarFile(filepath, all_names=True)
-            #logging.debug('files in rar file: %s', zf.namelist())
-            for somefile in zf.namelist() :
+            # logging.debug('files in rar file: %s', zf.namelist())
+            for somefile in zf.namelist():
                 logging.debug('file in rar file: %s', somefile)
                 if os.path.splitext(somefile)[1].replace('.', '').lower() in cfg.unwanted_extensions():
                     logging.debug('Unwanted file %s', somefile)
@@ -371,21 +349,25 @@ def rar_contains_unwanted_file(filepath):
             logging.debug('RAR file %s cannot be inspected.', filepath)
     return unwanted
 
+
 def nzo_filtered_by_rating(nzo):
-    if Rating.do and cfg.rating_enable() and cfg.rating_filter_enable() and (nzo.rating_filtered < 2):   
-        rating = Rating.do.get_rating_by_nzo(nzo.nzo_id)        
+    if Rating.do and cfg.rating_enable() and cfg.rating_filter_enable() and (nzo.rating_filtered < 2):
+        rating = Rating.do.get_rating_by_nzo(nzo.nzo_id)
         if rating is not None:
             nzo.rating_filtered = 1
             reason = rating_filtered(rating, nzo.filename.lower(), True)
-            if reason is not None: return (2, reason)
+            if reason is not None:
+                return (2, reason)
             reason = rating_filtered(rating, nzo.filename.lower(), False)
-            if reason is not None: return (1, reason)
+            if reason is not None:
+                return (1, reason)
     return (0, "")
-    
+
+
 def rating_filtered(rating, filename, abort):
     def check_keyword(keyword):
         clean_keyword = keyword.strip().lower()
-        return (len(clean_keyword) > 0) and (clean_keyword in filename) 
+        return (len(clean_keyword) > 0) and (clean_keyword in filename)
     audio = cfg.rating_filter_abort_audio() if abort else cfg.rating_filter_pause_audio()
     video = cfg.rating_filter_abort_video() if abort else cfg.rating_filter_pause_video()
     spam = cfg.rating_filter_abort_spam() if abort else cfg.rating_filter_pause_spam()
