@@ -1,5 +1,5 @@
 #!/usr/bin/python -OO
-# Copyright 2008-2012 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2015 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,7 +18,6 @@
 """
 sabnzbd.emailer - Send notification emails
 """
-#------------------------------------------------------------------------------
 
 from sabnzbd.utils import ssmtplib
 import smtplib
@@ -30,39 +29,40 @@ import glob
 from sabnzbd.constants import *
 import sabnzbd
 from sabnzbd.misc import to_units, split_host, time_format
-from sabnzbd.encoding import EmailFilter, latin1
+from sabnzbd.encoding import EmailFilter
 import sabnzbd.cfg as cfg
 
+
 def errormsg(msg):
-    logging.error(latin1(msg))
+    logging.error(msg)
     return msg
 
 
-
-################################################################################
+##############################################################################
 # EMAIL_SEND
-#
-#
-################################################################################
+##############################################################################
 def send(message, email_to, test=None):
     """ Send message if message non-empty and email-parms are set """
 
+    def utf8(p):
+        return p.encode('utf8', 'ignore')
+
     # we should not use CFG if we are testing. we should use values
     # from UI instead.
 
     if test:
-        email_server  = test.get('email_server')
-        email_from    = test.get('email_from')
-        email_account = test.get('email_account')
-        email_pwd     = test.get('email_pwd')
+        email_server = utf8(test.get('email_server'))
+        email_from = utf8(test.get('email_from'))
+        email_account = utf8(test.get('email_account'))
+        email_pwd = utf8(test.get('email_pwd'))
         if email_pwd and not email_pwd.replace('*', ''):
             # If all stars, get stored password instead
-            email_pwd = cfg.email_pwd()
+            email_pwd = utf8(cfg.email_pwd())
     else:
-        email_server  = cfg.email_server()
-        email_from    = cfg.email_from()
-        email_account = cfg.email_account()
-        email_pwd     = cfg.email_pwd()
+        email_server = utf8(cfg.email_server())
+        email_from = utf8(cfg.email_from())
+        email_account = utf8(cfg.email_account())
+        email_pwd = utf8(cfg.email_pwd())
 
     # email_to is replaced at send_with_template, since it can be an array
 
@@ -89,7 +89,7 @@ def send(message, email_to, test=None):
             if errorcode[0]:
 
                 # Non SSL mail server
-                logging.debug("Non-SSL mail server detected " \
+                logging.debug("Non-SSL mail server detected "
                              "reconnecting to server %s:%s", server, port)
 
                 try:
@@ -147,25 +147,21 @@ def send(message, email_to, test=None):
         if msg:
             return msg
         else:
-            logging.info("Notification e-mail succesfully sent")
+            logging.info("Notification e-mail successfully sent")
             return T('Email succeeded')
 
 
 def get_email_date():
-    """ Return un-localized date string for the Date: field
-    """
+    """ Return un-localized date string for the Date: field """
     # Get locale indepedant date/time string: "Sun May 22 20:15:12 2011"
     day, month, dayno, hms, year = time.asctime(time.gmtime()).split()
     return '%s, %s %s %s %s +0000' % (day, dayno, month, year, hms)
 
 
-################################################################################
+##############################################################################
 # email_endjob
-#
-#
-################################################################################
+##############################################################################
 from Cheetah.Template import Template
-
 def send_with_template(prefix, parm, test=None):
     """ Send an email using template """
 
@@ -178,7 +174,7 @@ def send_with_template(prefix, parm, test=None):
         try:
             lst = glob.glob(os.path.join(path, '%s-*.tmpl' % prefix))
         except:
-            logging.error(Ta('Cannot find email templates in %s'), path)
+            logging.error(T('Cannot find email templates in %s'), path)
     else:
         path = os.path.join(sabnzbd.DIR_PROG, DEF_EMAIL_TMPL)
         tpath = os.path.join(path, '%s-%s.tmpl' % (prefix, cfg.language()))
@@ -194,7 +190,7 @@ def send_with_template(prefix, parm, test=None):
             if source:
                 sent = True
                 if test:
-                    recipients = [ test.get('email_to') ]
+                    recipients = [test.get('email_to')]
                 else:
                     recipients = cfg.email_to()
 
@@ -219,7 +215,7 @@ def send_with_template(prefix, parm, test=None):
     return ret
 
 
-def endjob(filename, msgid, cat, status, path, bytes, fail_msg, stages, script, script_output, script_ret, test=None):
+def endjob(filename, cat, status, path, bytes, fail_msg, stages, script, script_output, script_ret, test=None):
     """ Send end-of-job email """
 
     # Translate the stage names
@@ -236,20 +232,20 @@ def endjob(filename, msgid, cat, status, path, bytes, fail_msg, stages, script,
                 lines.extend(line.replace('<br/>', '\n').split('\n'))
             else:
                 lines.append(line)
-        xstages[tr('stage-'+stage.lower())] = lines
+        xstages[tr('stage-' + stage.lower())] = lines
 
     parm = {}
     parm['status'] = status
     parm['name'] = filename
     parm['path'] = path
-    parm['msgid'] = str(msgid)
+    parm['msgid'] = ''
     parm['stages'] = xstages
     parm['script'] = script
     parm['script_output'] = script_output
     parm['script_ret'] = script_ret
     parm['cat'] = cat
     parm['size'] = "%sB" % to_units(bytes)
-    parm['end_time'] = time.strftime(time_format('%Y-%m-%d %H:%M:%S'), time.localtime(time.time()))
+    parm['end_time'] = time.strftime(time_format('%Y-%m-%d %H:%M:%S'), time.localtime(time.time())).decode(codepage)
 
     return send_with_template('email', parm, test)
 
@@ -257,22 +253,20 @@ def endjob(filename, msgid, cat, status, path, bytes, fail_msg, stages, script,
 def rss_mail(feed, jobs):
     """ Send notification email containing list of files """
 
-    parm = {'amount' : len(jobs), 'feed' : feed, 'jobs' : jobs}
+    parm = {'amount': len(jobs), 'feed': feed, 'jobs': jobs}
     return send_with_template('rss', parm)
 
 
 def badfetch_mail(msg, url):
     """ Send notification email about failed NZB fetch """
 
-    parm = {'url' : url, 'msg' : msg}
+    parm = {'url': url, 'msg': msg}
     return send_with_template('badfetch', parm)
 
 
-################################################################################
+##############################################################################
 # EMAIL_DISKFULL
-#
-#
-################################################################################
+##############################################################################
 def diskfull():
     """ Send email about disk full, no templates """
 
@@ -314,13 +308,12 @@ def _decode_file(path):
         return ''
 
 
-################################################################################
+##############################################################################
 from email.message import Message
 from email.header import Header
 from email.encoders import encode_quopri
 
 RE_HEADER = re.compile(r'^([^:]+):(.*)')
-
 def _prepare_message(txt):
     """ Apply the proper encoding to all email fields.
         The body will be Latin-1, the headers will be 'quopri'd when necessary.
