@@ -21,6 +21,7 @@ sabnzbd.rating - Rating support functions
 
 import httplib
 import urllib
+import urlparse
 import time
 import logging
 import copy
@@ -30,28 +31,33 @@ try:
     _HAVE_SSL = True
 except:
     _HAVE_SSL = False
-from threading import *
+from threading import RLock, Thread
 
 import sabnzbd
 from sabnzbd.decorators import synchronized
-from sabnzbd.misc import OrderedSetQueue
+from sabnzbd.utils.ordered import OrderedSetQueue
 import sabnzbd.cfg as cfg
 
-RATING_URL = "/releaseRatings/releaseRatings.php"
+_RATING_URL = "/releaseRatings/releaseRatings.php"
 RATING_LOCK = RLock()
 
 _g_warnings = 0
+
+
 def _warn(msg):
     global _g_warnings
     _g_warnings += 1
     if _g_warnings < 3:
         logging.warning(msg)
 
+
 def _reset_warn():
     global _g_warnings
     _g_warnings = 0
 
+
 class NzbRating(object):
+
     def __init__(self):
         self.avg_video = 0
         self.avg_video_cnt = 0
@@ -66,18 +72,21 @@ class NzbRating(object):
         self.auto_flag = {}
         self.changed = 0
 
+
 class NzbRatingV2(NzbRating):
+
     def __init__(self):
         super(NzbRatingV2, self).__init__()
         self.avg_spam_cnt = 0
         self.avg_spam_confirm = False
         self.avg_encrypted_cnt = 0
         self.avg_encrypted_confirm = False
-        
+
     def to_v2(self, rating):
         self.__dict__.update(rating.__dict__)
         return self
-    
+
+
 class Rating(Thread):
     VERSION = 2
 
@@ -104,14 +113,15 @@ class Rating(Thread):
         self.shutdown = False
         self.queue = OrderedSetQueue()
         try:
-            (self.version, self.ratings, self.nzo_indexer_map) = sabnzbd.load_admin("Rating.sab")
+            self.version, self.ratings, self.nzo_indexer_map = sabnzbd.load_admin("Rating.sab",
+                                                                                  silent=not cfg.rating_enable())
             if self.version == 1:
                 ratings = {}
                 for k, v in self.ratings.iteritems():
                     ratings[k] = NzbRatingV2().to_v2(v)
                 self.ratings = ratings
                 self.version = 2
-            if (self.version != Rating.VERSION):
+            if self.version != Rating.VERSION:
                 raise Exception()
         except:
             self.version = Rating.VERSION
@@ -119,23 +129,25 @@ class Rating(Thread):
             self.nzo_indexer_map = {}
         Thread.__init__(self)
         if not _HAVE_SSL:
-            logging.warning('Ratings server requires secure connection')
+            logging.warning(T('Ratings server requires secure connection'))
             self.stop()
 
     def stop(self):
         self.shutdown = True
-        self.queue.put(None) # Unblock queue
+        self.queue.put(None)  # Unblock queue
 
     def run(self):
         self.shutdown = False
         while not self.shutdown:
             time.sleep(1)
-            if not cfg.rating_enable(): continue
+            if not cfg.rating_enable():
+                continue
             indexer_id = self.queue.get()
             try:
                 if indexer_id and not self._send_rating(indexer_id):
-                    for i in range(0, 60):
-                        if self.shutdown: break
+                    for unused in range(0, 60):
+                        if self.shutdown:
+                            break
                         time.sleep(1)
                     self.queue.put(indexer_id)
             except:
@@ -149,8 +161,8 @@ class Rating(Thread):
 
     # The same file may be uploaded multiple times creating a new nzo_id each time
     @synchronized(RATING_LOCK)
-    def add_rating(self, indexer_id, nzo_id, host, fields):
-        if indexer_id and nzo_id and (len(fields) == 10):
+    def add_rating(self, indexer_id, nzo_id, fields):
+        if indexer_id and nzo_id:
             logging.debug('Add rating (%s, %s: %s, %s, %s, %s)', indexer_id, nzo_id, fields['video'], fields['audio'], fields['voteup'], fields['votedown'])
             try:
                 rating = self.ratings.get(indexer_id, NzbRatingV2())
@@ -160,23 +172,33 @@ class Rating(Thread):
                 if fields['audio'] and fields['audiocnt']:
                     rating.avg_audio = int(float(fields['audio']))
                     rating.avg_audio_cnt = int(float(fields['audiocnt']))
-                if fields['voteup']: rating.avg_vote_up = int(float(fields['voteup']))
-                if fields['votedown']: rating.avg_vote_down = int(float(fields['votedown']))
-                if fields['spam']: rating.avg_spam_cnt = int(float(fields['spam']))
-                if fields['confirmed-spam']: rating.avg_spam_confirm = (fields['confirmed-spam'].lower() == 'yes')
-                if fields['passworded']: rating.avg_encrypted_cnt = int(float(fields['passworded']))                
-                if fields['confirmed-passworded']: rating.avg_encrypted_confirm = (fields['confirmed-passworded'].lower() == 'yes')
-                rating.host = host[0] if host and isinstance(host, list) else host
+                if fields['voteup']:
+                    rating.avg_vote_up = int(float(fields['voteup']))
+                if fields['votedown']:
+                    rating.avg_vote_down = int(float(fields['votedown']))
+                if fields['spam']:
+                    rating.avg_spam_cnt = int(float(fields['spam']))
+                if fields['confirmed-spam']:
+                    rating.avg_spam_confirm = (fields['confirmed-spam'].lower() == 'yes')
+                if fields['passworded']:
+                    rating.avg_encrypted_cnt = int(float(fields['passworded']))
+                if fields['confirmed-passworded']:
+                    rating.avg_encrypted_confirm = (fields['confirmed-passworded'].lower() == 'yes')
+                # Indexers can supply a full URL or just a host
+                if fields['host']:
+                    rating.host = fields['host'][0] if fields['host'] and isinstance(fields['host'], list) else fields['host']
+                if fields['url']:
+                    rating.host = fields['url'][0] if fields['url'] and isinstance(fields['url'], list) else fields['url']
                 self.ratings[indexer_id] = rating
                 self.nzo_indexer_map[nzo_id] = indexer_id
             except:
                 pass
 
     @synchronized(RATING_LOCK)
-    def update_user_rating(self, nzo_id, video, audio, vote, flag, flag_detail = None):
+    def update_user_rating(self, nzo_id, video, audio, vote, flag, flag_detail=None):
         logging.debug('Updating user rating (%s: %s, %s, %s, %s)', nzo_id, video, audio, vote, flag)
         if nzo_id not in self.nzo_indexer_map:
-            logging.warning('indexer id (%s) not found for ratings file', nzo_id)
+            logging.warning(T('Indexer id (%s) not found for ratings file'), nzo_id)
             return
         indexer_id = self.nzo_indexer_map[nzo_id]
         rating = self.ratings[indexer_id]
@@ -189,25 +211,32 @@ class Rating(Thread):
             rating.avg_audio = int((rating.avg_audio_cnt * rating.avg_audio + rating.user_audio) / (rating.avg_audio_cnt + 1))
             rating.changed = rating.changed | Rating.CHANGED_USER_AUDIO
         if flag:
-            rating.user_flag = { 'val': int(flag), 'detail': flag_detail }
+            rating.user_flag = {'val': int(flag), 'detail': flag_detail}
             rating.changed = rating.changed | Rating.CHANGED_USER_FLAG
-        if vote and not rating.user_vote:
-            rating.user_vote = int(vote)
+        if vote:
             rating.changed = rating.changed | Rating.CHANGED_USER_VOTE
-            if rating.user_vote == Rating.VOTE_UP:
+            if int(vote) == Rating.VOTE_UP:
                 rating.avg_vote_up += 1
+                # Update if already a vote
+                if rating.user_vote and rating.user_vote == Rating.VOTE_DOWN:
+                    rating.avg_vote_down -= 1
             else:
                 rating.avg_vote_down += 1
+                # Update if already a vote
+                if rating.user_vote and rating.user_vote == Rating.VOTE_UP:
+                    rating.avg_vote_up -= 1
+
+            rating.user_vote = int(vote)
         self.queue.put(indexer_id)
 
     @synchronized(RATING_LOCK)
-    def update_auto_flag(self, nzo_id, flag, flag_detail = None):
+    def update_auto_flag(self, nzo_id, flag, flag_detail=None):
         if not flag or not cfg.rating_enable() or not cfg.rating_feedback() or (nzo_id not in self.nzo_indexer_map):
             return
         logging.debug('Updating auto flag (%s: %s)', nzo_id, flag)
         indexer_id = self.nzo_indexer_map[nzo_id]
         rating = self.ratings[indexer_id]
-        rating.auto_flag = { 'val': int(flag), 'detail': flag_detail }
+        rating.auto_flag = {'val': int(flag), 'detail': flag_detail}
         rating.changed = rating.changed | Rating.CHANGED_AUTO_FLAG
         self.queue.put(indexer_id)
 
@@ -239,14 +268,19 @@ class Rating(Thread):
 
         api_key = cfg.rating_api_key()
         rating_host = cfg.rating_host()
+        rating_url = _RATING_URL
         if not api_key:
             return True
 
         requests = []
-        _headers = {'User-agent' : 'SABnzbd+/%s' % sabnzbd.version.__version__, 'Content-type': 'application/x-www-form-urlencoded'}
-        rating = self._get_rating_by_indexer(indexer_id) # Requesting info here ensures always have latest information even on retry
+        _headers = {'User-agent': 'SABnzbd+/%s' % sabnzbd.version.__version__, 'Content-type': 'application/x-www-form-urlencoded'}
+        rating = self._get_rating_by_indexer(indexer_id)  # Requesting info here ensures always have latest information even on retry
         if hasattr(rating, 'host') and rating.host:
-            rating_host = rating.host
+            host_parsed = urlparse.urlparse(rating.host)
+            rating_host = host_parsed.netloc
+            # Is it an URL or just a HOST?
+            if host_parsed.path and host_parsed.path != '/':
+                rating_url = host_parsed.path + '?' + host_parsed.query if host_parsed.query else host_parsed.path
         if not rating_host:
             return True
         if rating.changed & Rating.CHANGED_USER_VIDEO:
@@ -264,9 +298,10 @@ class Rating(Thread):
         try:
             conn = httplib.HTTPSConnection(rating_host)
             for request in filter(lambda r: r is not None, requests):
-                request['apikey'] = api_key
-                request['i'] =  indexer_id
-                conn.request('POST', RATING_URL, urllib.urlencode(request), headers = _headers)
+                if api_key:
+                    request['apikey'] = api_key
+                request['i'] = indexer_id
+                conn.request('POST', rating_url, urllib.urlencode(request), headers=_headers)
 
                 response = conn.getresponse()
                 response.read()
@@ -276,7 +311,6 @@ class Rating(Thread):
                 elif response.status != httplib.OK:
                     _warn('Ratings server failed to process request (%s, %s)' % (response.status, response.reason))
                     return False
-
             self.ratings[indexer_id].changed = self.ratings[indexer_id].changed & ~rating.changed
             _reset_warn()
             return True
