@@ -1,5 +1,5 @@
 #!/usr/bin/python -OO
-# Copyright 2008-2012 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2015 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -21,13 +21,14 @@ sabnzbd.utils.servertests - Debugging server connections. Currently only NNTP se
 
 import socket
 import sys
+import select
 
 from sabnzbd.newswrapper import NewsWrapper
 from sabnzbd.downloader import Server, clues_login, clues_too_many
 from sabnzbd.config import get_servers
-from sabnzbd.encoding import xml_name
 from sabnzbd.misc import int_conv
 
+
 def test_nntp_server_dict(kwargs):
     # Grab the host/port/user/pass/connections/ssl
     host = kwargs.get('host', '').strip()
@@ -40,6 +41,7 @@ def test_nntp_server_dict(kwargs):
     if not connections:
         return False, T('There are no connections set. Please set at least one connection.')
     ssl = int_conv(kwargs.get('ssl', 0))
+    ssl_type = kwargs.get('ssl_type')
     port = int_conv(kwargs.get('port', 0))
     if not port:
         if ssl:
@@ -47,13 +49,12 @@ def test_nntp_server_dict(kwargs):
         else:
             port = 119
 
-
-    return test_nntp_server(host, port, server, username=username, \
-                        password=password, ssl=ssl)
+    return test_nntp_server(host, port, server, username=username,
+                        password=password, ssl=ssl, ssl_type=ssl_type)
 
 
-def test_nntp_server(host, port, server=None, username=None, password=None, ssl=None):
-    ''' Will connect (blocking) to the nttp server and report back any errors '''
+def test_nntp_server(host, port, server=None, username=None, password=None, ssl=None, ssl_type=None):
+    """ Will connect (blocking) to the nttp server and report back any errors """
     timeout = 4.0
     if '*' in password and not password.strip('*'):
         # If the password is masked, try retrieving it from the config
@@ -73,7 +74,7 @@ def test_nntp_server(host, port, server=None, username=None, password=None, ssl=
         if not got_pass:
             return False, T('Password masked in ******, please re-enter')
     try:
-        s = Server(-1, host, port, timeout, 0, 0, ssl, username, password)
+        s = Server(-1, '', host, port, timeout, 0, 0, ssl, ssl_type, False, username, password)
     except:
         return False, T('Invalid server details')
 
@@ -83,6 +84,10 @@ def test_nntp_server(host, port, server=None, username=None, password=None, ssl=
         while not nw.connected:
             nw.lines = []
             nw.recv_chunk(block=True)
+            #more ssl related: handle 1/n-1 splitting to prevent Rizzo/Duong-Beast
+            read_sockets, _, _ = select.select([nw.nntp.sock], [], [], 0.1)
+            if read_sockets:
+                nw.recv_chunk(block=True)
             nw.finish_connect(nw.lines[0][:3])
 
     except socket.timeout, e:
@@ -91,18 +96,17 @@ def test_nntp_server(host, port, server=None, username=None, password=None, ssl=
         else:
             return False, T('Timed out')
     except socket.error, e:
-        return False, xml_name(str(e))
+        return False, unicode(e)
 
     except TypeError, e:
-        return False, xml_name(T('Invalid server address.'))
+        return False, T('Invalid server address.')
 
     except IndexError:
         # No data was received in recv_chunk() call
-        return False, xml_name(T('Server quit during login sequence.'))
+        return False, T('Server quit during login sequence.')
 
     except:
-        return False, xml_name(str(sys.exc_info()[1]))
-
+        return False, unicode(sys.exc_info()[1])
 
     if not username or not password:
         nw.nntp.sock.sendall('ARTICLE <test@home>\r\n')
@@ -110,7 +114,7 @@ def test_nntp_server(host, port, server=None, username=None, password=None, ssl=
             nw.lines = []
             nw.recv_chunk(block=True)
         except:
-            return False, xml_name(str(sys.exc_info()[1]))
+            return False, unicode(sys.exc_info()[1])
 
     # Could do with making a function for return codes to be used by downloader
     try:
@@ -132,7 +136,7 @@ def test_nntp_server(host, port, server=None, username=None, password=None, ssl=
         return False, T('Too many connections, please pause downloading or try again later')
 
     else:
-        return False, T('Could not determine connection result (%s)') % xml_name(nw.lines[0])
+        return False, T('Could not determine connection result (%s)') % nw.lines[0]
 
     # Close the connection
     nw.terminate(quit=True)
