@@ -1,8 +1,8 @@
 # This file will be patched by setup.py
 # The __version__ should be set to the branch name
-# (e.g. "trunk" or "0.4.x")
+# (e.g. "develop" or "1.2.x")
 
 # You MUST use double quotes (so " and not ')
 
-__version__ = "0.7.20"
-__baseline__ = "1df2943d05d64915a166e2c97e1eef86f72e3ff3"
+__version__ = "1.1.1"
+__baseline__ = "33a7874416d8a8cc6a0d1e3f8d1e4042f2762d81"
