@@ -25,7 +25,6 @@ import cherrypy
 from Cheetah.Template import Template
 
 import sabnzbd
-from sabnzbd.constants import *
 import sabnzbd.api
 from sabnzbd.lang import list_languages, set_language
 from sabnzbd.utils.servertests import test_nntp_server_dict
@@ -135,7 +134,7 @@ class Wizard(object):
 
         # Show Restart screen
         info = self.info.copy()
-        info['helpuri'] = 'http://wiki.sabnzbd.org/'
+        info['helpuri'] = 'https://sabnzbd.org/wiki/'
         info['session'] = cfg.api_key()
 
         info['access_url'], info['urls'] = self.get_access_info()
